@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Webmozart\Assert\Tests\StaticAnalysis;
 
 use Webmozart\Assert\Assert;
@@ -9,7 +11,7 @@ use Webmozart\Assert\Assert;
  *
  * @return class-string
  */
-function interfaceExists($value): string
+function interfaceExists(mixed $value): string
 {
     Assert::interfaceExists($value);
 
@@ -21,7 +23,7 @@ function interfaceExists($value): string
  *
  * @return null|class-string
  */
-function nullOrInterfaceExists($value): ?string
+function nullOrInterfaceExists(mixed $value): ?string
 {
     Assert::nullOrInterfaceExists($value);
 
@@ -30,10 +32,8 @@ function nullOrInterfaceExists($value): ?string
 
 /**
  * @param mixed $value
- *
- * @return iterable<class-string>
  */
-function allInterfaceExists($value): iterable
+function allInterfaceExists(mixed $value): iterable
 {
     Assert::allInterfaceExists($value);
 
@@ -42,10 +42,8 @@ function allInterfaceExists($value): iterable
 
 /**
  * @param mixed $value
- *
- * @return iterable<class-string|null>
  */
-function allNullOrInterfaceExists($value): iterable
+function allNullOrInterfaceExists(mixed $value): iterable
 {
     Assert::allNullOrInterfaceExists($value);
 
